@@ -3,7 +3,7 @@
 # @Author: jorisbontje
 # @Date:   2014-08-03 13:53:04
 # @Last Modified by:   caktux
-# @Last Modified time: 2014-12-23 06:47:11
+# @Last Modified time: 2014-12-24 03:14:12
 
 import json
 import logging
@@ -133,12 +133,12 @@ class Api(object):
         params = [address]
         return self._rpc_post('eth_storageAt', params)
 
-    def transact(self, dest, from_=config.get("api", "address"), funid=None, data="", gas=config.get("deploy", "gas"), gas_price=config.get("deploy", "gas_price"), value=0):
+    def transact(self, dest, from_=config.get("api", "address"), funid=None, data=None, gas=config.get("deploy", "gas"), gas_price=config.get("deploy", "gas_price"), value=0):
         if not dest.startswith('0x'):
             dest = '0x' + dest
 
         if funid is not None:
-            data_abi = serpent.encode_abi(funid, data).encode('hex')
+            data_abi = serpent.encode_abi(funid, *data).encode('hex')
             logger.debug("ABI data: 0x%s" % data_abi)
             data = "0x" + data_abi
 
@@ -150,19 +150,18 @@ class Api(object):
             'value': hex(value)}]
         return self._rpc_post('eth_transact', params)
 
-    def call(self, dest, from_=config.get("api", "address"), funid=None, data="", gas=config.get("deploy", "gas"), gas_price=config.get("deploy", "gas_price"), value=0):
+    def call(self, dest, from_=config.get("api", "address"), funid=None, data=None, gas=config.get("deploy", "gas"), gas_price=config.get("deploy", "gas_price"), value=0):
         if not dest.startswith('0x'):
             dest = '0x' + dest
 
         if funid is not None:
-            data_abi = serpent.encode_abi(funid, data).encode('hex')
+            data_abi = serpent.encode_abi(funid, *data).encode('hex')
             logger.debug("ABI data: 0x%s" % data_abi)
             data = "0x" + data_abi
 
         params = [{
             'to': dest,
             'data': data,
-            'from': from_,
             'gas': hex(gas),
             'gasPrice': hex(gas_price),
             'value': hex(value)}]
